#
# git clone https://github.com/alexkay/spek.git
# cd spek
# DATE=$(git log -1 --format="%cd" --date=short | sed "s|-||g")
# git config tar.tar.xz.command "xz -c"
# git archive --format=tar.xz -o spek-${DATE}.tar.xz --prefix=spek-${DATE}/ master
#

#global gdate	20220409

Name:		spek
Version:	0.8.5%{?gdate:^git%gdate}
Release:	%mkrel 2
Group:		Sound/Utilities
License:	GPLv3
Summary:	Tool for audio spectrum analysis and visualization
URL:		http://spek.cc/
Source0:	https://github.com/alexkay/spek/archive/v%{version}/%{name}-%{?gdate}%{!?gdate:%version}.tar.%{?gdate:xz}%{!?gdate:gz}
BuildRequires:	wxgtk-devel
BuildRequires:	ffmpeg-devel
BuildRequires:	intltool

%description
Spek (IPA: /spɛk/, ‘bacon’ in Dutch) helps to analyse your audio files by showing
their spectrogram. Spek is free software available for Unix, Windows and Mac OS X.

Features:

* Supports all popular lossy and lossless audio file formats thanks to the FFmpeg libraries.
* Ultra-fast signal processing, uses multiple threads to further speed up the analysis.
* Shows the codec name and the audio signal parameters.
* Allows to save the spectrogram as an image file.
* Drag-and-drop support; associates with common audio file formats.
* Auto-fitting time, frequency and spectral density rulers.
* Adjustable spectral density range.
* Translated into 16 languages.

%prep
%autosetup -p1 -n %{name}-%{?gdate}%{!?gdate:%version}

%build
NOCONFIGURE=1 ./autogen.sh
%configure
%make_build

%install
%make_install

%find_lang %{name}

%files -f %{name}.lang
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/spek.{png,svg}
%{_mandir}/man1/%{name}.*


%changelog
* Sun Dec 08 2024 daviddavid <daviddavid> 0.8.5-2.mga10
+ Revision: 2122654
- rebuild for new ffmpeg 7.1

* Sat Jan 28 2023 wally <wally> 0.8.5-1.mga9
+ Revision: 1936655
- new version 0.8.5

* Sat Jan 28 2023 wally <wally> 0.8.3^git20220409-4.mga9
+ Revision: 1936631
- don't own hicolor icon dirs

* Fri Jul 15 2022 wally <wally> 0.8.3^git20220409-3.mga9
+ Revision: 1868999
- rebuild for wxgtk 3.2.0

* Sun Jun 12 2022 wally <wally> 0.8.3^git20220409-2.mga9
+ Revision: 1864108
- rebuild for wxgtk 3.1.7

* Sun Apr 17 2022 wally <wally> 0.8.3^git20220409-1.mga9
+ Revision: 1851031
- update to latest git snapshot
- add patch to fix build with ffmepg5
- rebuild for wxgtk 3.1.6
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Sat Jan 15 2022 wally <wally> 0.8.3-17.mga9
+ Revision: 1768502
- rebuild for wxgtk 3.1.5 with working wxSizer::SetSizeHints()

* Sat Jan 01 2022 wally <wally> 0.8.3-16.mga9
+ Revision: 1765711
- rebuild for wxgtk 3.1.5 to resolve 'Symbol X has different size in shared object, consider re-linking' error

* Fri Jan 01 2021 wally <wally> 0.8.3-15.mga8
+ Revision: 1667728
- rebuild for wxgtk pre 3.1.5 snapshot

* Sat Nov 07 2020 wally <wally> 0.8.3-14.mga8
+ Revision: 1643540
- fix build with autoconf 2.69d

* Sun Aug 16 2020 wally <wally> 0.8.3-13.mga8
+ Revision: 1614369
- rebuild for new wxgtk 3.1.4

* Tue Feb 18 2020 umeabot <umeabot> 0.8.3-12.mga8
+ Revision: 1538031
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Nov 12 2019 wally <wally> 0.8.3-11.mga8
+ Revision: 1459490
- rebuild for wxgtk 3.1.3

* Mon Jul 08 2019 wally <wally> 0.8.3-10.mga8
+ Revision: 1419535
- rebuild for wxgtk 3.1.2 with 2.8 compatibility

* Sun Jun 30 2019 wally <wally> 0.8.3-9.mga8
+ Revision: 1416372
- rebuild with gtk3 enabled wxgtk 3.1.2

* Sun Sep 23 2018 umeabot <umeabot> 0.8.3-8.mga7
+ Revision: 1301140
- Mageia 7 Mass Rebuild

* Sat Apr 28 2018 daviddavid <daviddavid> 0.8.3-7.mga7
+ Revision: 1223016
- rebuild for new ffmpeg 4.0

* Sat Jun 03 2017 akien <akien> 0.8.3-6.mga6
+ Revision: 1106127
- Rebuild for wxgtk 3.0.3.1

* Tue May 02 2017 akien <akien> 0.8.3-5.mga6
+ Revision: 1098322
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 0.8.3-4.mga6
+ Revision: 1090257
- Rebuild for ffmpeg 3.2.4

* Sat Feb 18 2017 cjw <cjw> 0.8.3-3.mga6
+ Revision: 1086676
- use current wxgtk
- patch1: fix build with ffmpeg 3.2.x
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sun Dec 13 2015 daviddavid <daviddavid> 0.8.3-1.mga6
+ Revision: 909833
- new version: 0.8.3
- update URL and Source URL

* Fri Nov 14 2014 cjw <cjw> 0.8.2-5.mga5
+ Revision: 796949
- rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 0.8.2-4.mga5
+ Revision: 748273
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.8.2-3.mga5
+ Revision: 689282
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 0.8.2-2.mga4
+ Revision: 541256
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 mitya <mitya> 0.8.2-1.mga4
+ Revision: 495404
- New version 0.8.2

* Fri Jul 12 2013 fwang <fwang> 0.8.1-4.mga4
+ Revision: 453382
- fix build with recent ffmpeg

* Mon Jan 14 2013 umeabot <umeabot> 0.8.1-4.mga3
+ Revision: 382517
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 malo <malo> 0.8.1-3.mga3
+ Revision: 343376
- updated RPM group (Visualization is no more)

* Tue Jan 08 2013 fwang <fwang> 0.8.1-2.mga3
+ Revision: 341743
- rebuild for new ffmpeg

* Thu Nov 22 2012 mitya <mitya> 0.8.1-1.mga3
+ Revision: 320424
- 0.8.1
- Created package structure for spek.

